summaryrefslogtreecommitdiff
path: root/firmware/lib/vboot_ui_legacy_wilco.c
diff options
context:
space:
mode:
Diffstat (limited to 'firmware/lib/vboot_ui_legacy_wilco.c')
-rw-r--r--firmware/lib/vboot_ui_legacy_wilco.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/firmware/lib/vboot_ui_legacy_wilco.c b/firmware/lib/vboot_ui_legacy_wilco.c
index 2971a1bc..bbfd9aff 100644
--- a/firmware/lib/vboot_ui_legacy_wilco.c
+++ b/firmware/lib/vboot_ui_legacy_wilco.c
@@ -61,9 +61,9 @@ static vb2_error_t vb2_enter_vendor_data_ui(struct vb2_context *ctx,
case 0:
/* Nothing pressed */
break;
- case VB_KEY_ESC:
- /* Escape pressed - return to developer screen */
- VB2_DEBUG("Vendor Data UI - user pressed Esc: "
+ case VB_KEY_CTRL('S'):
+ /* Ctrl+S pressed - return to developer screen */
+ VB2_DEBUG("Vendor Data UI - user pressed Ctrl+S: "
"exit to Developer screen\n");
data_value[0] = '\0';
return VB2_SUCCESS;